@@ -1,6 +1,7 @@
+use std::{iter, mem::take};
+
 use either::Either;
 use serde::Deserialize;
-use std::{iter, mem::take};
 use swc_common::{Spanned, DUMMY_SP};
 use swc_ecma_ast::*;
 use swc_ecma_transforms_base::helper;
@@ -326,6 +327,9 @@ impl Decorators {
                     in_nested_scope: false,
                     in_injected_define_property_call: false,
                     this_alias_mark: None,
+                    // TODO: loose mode
+                    constant_super: false,
+                    super_class: &None,
                 });
 
                 let method = method.fold_with(&mut folder);
